@@ -20,11 +20,13 @@
 
 #include "db.h"
 #include "flags.h"
+#include "metrics.h"
 #include "state.pb.h"
 #include "timebase.h"
 
 using namespace bmusb;
 using namespace std;
+using namespace std::chrono;
 using namespace std::placeholders;
 
 namespace {
@@ -183,7 +185,18 @@ AudioMixer::AudioMixer(unsigned num_cards)
 	set_limiter_enabled(global_flags.limiter_enabled);
 	set_final_makeup_gain_auto(global_flags.final_makeup_gain_auto);
 
+	r128.init(2, OUTPUT_FREQUENCY);
+	r128.integr_start();
+
+	// hlen=16 is pretty low quality, but we use quite a bit of CPU otherwise,
+	// and there's a limit to how important the peak meter is.
+	peak_resampler.setup(OUTPUT_FREQUENCY, OUTPUT_FREQUENCY * 4, /*num_channels=*/2, /*hlen=*/16, /*frel=*/1.0);
+
+	global_audio_mixer = this;
+	alsa_pool.init();
+
 	if (!global_flags.input_mapping_filename.empty()) {
+		// Must happen after ALSAPool is initialized, as it needs to know the card list.
 		current_mapping_mode = MappingMode::MULTICHANNEL;
 		InputMapping new_input_mapping;
 		if (!load_input_mapping_from_file(get_devices(),
@@ -201,15 +214,13 @@ AudioMixer::AudioMixer(unsigned num_cards)
 		}
 	}
 
-	r128.init(2, OUTPUT_FREQUENCY);
-	r128.integr_start();
-
-	// hlen=16 is pretty low quality, but we use quite a bit of CPU otherwise,
-	// and there's a limit to how important the peak meter is.
-	peak_resampler.setup(OUTPUT_FREQUENCY, OUTPUT_FREQUENCY * 4, /*num_channels=*/2, /*hlen=*/16, /*frel=*/1.0);
-
-	global_audio_mixer = this;
-	alsa_pool.init();
+	global_metrics.add("audio_loudness_short_lufs", &metric_audio_loudness_short_lufs, Metrics::TYPE_GAUGE);
+	global_metrics.add("audio_loudness_integrated_lufs", &metric_audio_loudness_integrated_lufs, Metrics::TYPE_GAUGE);
+	global_metrics.add("audio_loudness_range_low_lufs", &metric_audio_loudness_range_low_lufs, Metrics::TYPE_GAUGE);
+	global_metrics.add("audio_loudness_range_high_lufs", &metric_audio_loudness_range_high_lufs, Metrics::TYPE_GAUGE);
+	global_metrics.add("audio_peak_dbfs", &metric_audio_peak_dbfs, Metrics::TYPE_GAUGE);
+	global_metrics.add("audio_final_makeup_gain_db", &metric_audio_final_makeup_gain_db, Metrics::TYPE_GAUGE);
+	global_metrics.add("audio_correlation", &metric_audio_correlation, Metrics::TYPE_GAUGE);
 }
 
 void AudioMixer::reset_resampler(DeviceSpec device_spec)
@@ -227,12 +238,13 @@ void AudioMixer::reset_resampler_mutex_held(DeviceSpec device_spec)
 	} else {
 		// TODO: ResamplingQueue should probably take the full device spec.
 		// (It's only used for console output, though.)
-		device->resampling_queue.reset(new ResamplingQueue(device_spec.index, device->capture_frequency, OUTPUT_FREQUENCY, device->interesting_channels.size()));
+		device->resampling_queue.reset(new ResamplingQueue(
+			device_spec.index, device->capture_frequency, OUTPUT_FREQUENCY, device->interesting_channels.size(),
+			global_flags.audio_queue_length_ms * 0.001));
 	}
-	device->next_local_pts = 0;
 }
 
-bool AudioMixer::add_audio(DeviceSpec device_spec, const uint8_t *data, unsigned num_samples, AudioFormat audio_format, int64_t frame_length)
+bool AudioMixer::add_audio(DeviceSpec device_spec, const uint8_t *data, unsigned num_samples, AudioFormat audio_format, int64_t frame_length, steady_clock::time_point frame_time)
 {
 	AudioDevice *device = find_audio_device(device_spec);
 
@@ -271,10 +283,14 @@ bool AudioMixer::add_audio(DeviceSpec device_spec, const uint8_t *data, unsigned
 		}
 	}
 
+	// If we changed frequency since last frame, we'll need to reset the resampler.
+	if (audio_format.sample_rate != device->capture_frequency) {
+		device->capture_frequency = audio_format.sample_rate;
+		reset_resampler_mutex_held(device_spec);
+	}
+
 	// Now add it.
-	int64_t local_pts = device->next_local_pts;
-	device->resampling_queue->add_input_samples(local_pts / double(TIMEBASE), audio.get(), num_samples);
-	device->next_local_pts = local_pts + frame_length;
+	device->resampling_queue->add_input_samples(frame_time, audio.get(), num_samples, ResamplingQueue::ADJUST_RATE);
 	return true;
 }
 
@@ -296,11 +312,7 @@ bool AudioMixer::add_silence(DeviceSpec device_spec, unsigned samples_per_frame,
 
 	vector<float> silence(samples_per_frame * num_channels, 0.0f);
 	for (unsigned i = 0; i < num_frames; ++i) {
-		device->resampling_queue->add_input_samples(device->next_local_pts / double(TIMEBASE), silence.data(), samples_per_frame);
-		// Note that if the format changed in the meantime, we have
-		// no way of detecting that; we just have to assume the frame length
-		// is always the same.
-		device->next_local_pts += frame_length;
+		device->resampling_queue->add_input_samples(steady_clock::now(), silence.data(), samples_per_frame, ResamplingQueue::DO_NOT_ADJUST_RATE);
 	}
 	return true;
 }
@@ -473,7 +485,7 @@ void apply_gain(float db, float last_db, vector<float> *samples)
 
 }  // namespace
 
-vector<float> AudioMixer::get_output(double pts, unsigned num_samples, ResamplingQueue::RateAdjustmentPolicy rate_adjustment_policy)
+vector<float> AudioMixer::get_output(steady_clock::time_point ts, unsigned num_samples, ResamplingQueue::RateAdjustmentPolicy rate_adjustment_policy)
 {
 	map<DeviceSpec, vector<float>> samples_card;
 	vector<float> samples_bus;
@@ -488,7 +500,7 @@ vector<float> AudioMixer::get_output(double pts, unsigned num_samples, Resamplin
 			memset(&samples_card[device_spec][0], 0, samples_card[device_spec].size() * sizeof(float));
 		} else {
 			device->resampling_queue->get_output_samples(
-				pts,
+				ts,
 				&samples_card[device_spec][0],
 				num_samples,
 				rate_adjustment_policy);
@@ -824,23 +836,35 @@ void AudioMixer::send_audio_level_callback()
 	double loudness_range_low = r128.range_min();
 	double loudness_range_high = r128.range_max();
 
+	metric_audio_loudness_short_lufs = loudness_s;
+	metric_audio_loudness_integrated_lufs = loudness_i;
+	metric_audio_loudness_range_low_lufs = loudness_range_low;
+	metric_audio_loudness_range_high_lufs = loudness_range_high;
+	metric_audio_peak_dbfs = to_db(peak);
+	metric_audio_final_makeup_gain_db = to_db(final_makeup_gain);
+	metric_audio_correlation = correlation.get_correlation();
+
 	vector<BusLevel> bus_levels;
 	bus_levels.resize(input_mapping.buses.size());
 	{
 		lock_guard<mutex> lock(compressor_mutex);
 		for (unsigned bus_index = 0; bus_index < bus_levels.size(); ++bus_index) {
-			bus_levels[bus_index].current_level_dbfs[0] = to_db(peak_history[bus_index][0].current_level);
-			bus_levels[bus_index].current_level_dbfs[1] = to_db(peak_history[bus_index][1].current_level);
-			bus_levels[bus_index].peak_level_dbfs[0] = to_db(peak_history[bus_index][0].current_peak);
-			bus_levels[bus_index].peak_level_dbfs[1] = to_db(peak_history[bus_index][1].current_peak);
-			bus_levels[bus_index].historic_peak_dbfs = to_db(
+			BusLevel &levels = bus_levels[bus_index];
+			BusMetrics &metrics = bus_metrics[bus_index];
+
+			levels.current_level_dbfs[0] = metrics.current_level_dbfs[0] = to_db(peak_history[bus_index][0].current_level);
+			levels.current_level_dbfs[1] = metrics.current_level_dbfs[1] = to_db(peak_history[bus_index][1].current_level);
+			levels.peak_level_dbfs[0] = metrics.peak_level_dbfs[0] = to_db(peak_history[bus_index][0].current_peak);
+			levels.peak_level_dbfs[1] = metrics.peak_level_dbfs[1] = to_db(peak_history[bus_index][1].current_peak);
+			levels.historic_peak_dbfs = metrics.historic_peak_dbfs = to_db(
 				max(peak_history[bus_index][0].historic_peak,
 				    peak_history[bus_index][1].historic_peak));
-			bus_levels[bus_index].gain_staging_db = gain_staging_db[bus_index];
+			levels.gain_staging_db = metrics.gain_staging_db = gain_staging_db[bus_index];
 			if (compressor_enabled[bus_index]) {
-				bus_levels[bus_index].compressor_attenuation_db = -to_db(compressor[bus_index]->get_attenuation());
+				levels.compressor_attenuation_db = metrics.compressor_attenuation_db = -to_db(compressor[bus_index]->get_attenuation());
 			} else {
-				bus_levels[bus_index].compressor_attenuation_db = 0.0;
+				levels.compressor_attenuation_db = 0.0;
+				metrics.compressor_attenuation_db = 0.0 / 0.0;
 			}
 		}
 	}
@@ -963,6 +987,62 @@ void AudioMixer::set_input_mapping_lock_held(const InputMapping &new_input_mappi
 		}
 	}
 
+	// Kill all the old metrics, and set up new ones.
+	for (unsigned bus_index = 0; bus_index < input_mapping.buses.size(); ++bus_index) {
+		BusMetrics &metrics = bus_metrics[bus_index];
+
+		vector<pair<string, string>> labels_left = metrics.labels;
+		labels_left.emplace_back("channel", "left");
+		vector<pair<string, string>> labels_right = metrics.labels;
+		labels_right.emplace_back("channel", "right");
+
+		global_metrics.remove("bus_current_level_dbfs", labels_left);
+		global_metrics.remove("bus_current_level_dbfs", labels_right);
+		global_metrics.remove("bus_peak_level_dbfs", labels_left);
+		global_metrics.remove("bus_peak_level_dbfs", labels_right);
+		global_metrics.remove("bus_historic_peak_dbfs", metrics.labels);
+		global_metrics.remove("bus_gain_staging_db", metrics.labels);
+		global_metrics.remove("bus_compressor_attenuation_db", metrics.labels);
+	}
+	bus_metrics.reset(new BusMetrics[new_input_mapping.buses.size()]);
+	for (unsigned bus_index = 0; bus_index < new_input_mapping.buses.size(); ++bus_index) {
+		const InputMapping::Bus &bus = new_input_mapping.buses[bus_index];
+		BusMetrics &metrics = bus_metrics[bus_index];
+
+		char bus_index_str[16], source_index_str[16], source_channels_str[64];
+		snprintf(bus_index_str, sizeof(bus_index_str), "%u", bus_index);
+		snprintf(source_index_str, sizeof(source_index_str), "%u", bus.device.index);
+		snprintf(source_channels_str, sizeof(source_channels_str), "%d:%d", bus.source_channel[0], bus.source_channel[1]);
+
+		vector<pair<string, string>> labels;
+		metrics.labels.emplace_back("index", bus_index_str);
+		metrics.labels.emplace_back("name", bus.name);
+		if (bus.device.type == InputSourceType::SILENCE) {
+			metrics.labels.emplace_back("source_type", "silence");
+		} else if (bus.device.type == InputSourceType::CAPTURE_CARD) {
+			metrics.labels.emplace_back("source_type", "capture_card");
+		} else if (bus.device.type == InputSourceType::ALSA_INPUT) {
+			metrics.labels.emplace_back("source_type", "alsa_input");
+		} else {
+			assert(false);
+		}
+		metrics.labels.emplace_back("source_index", source_index_str);
+		metrics.labels.emplace_back("source_channels", source_channels_str);
+
+		vector<pair<string, string>> labels_left = metrics.labels;
+		labels_left.emplace_back("channel", "left");
+		vector<pair<string, string>> labels_right = metrics.labels;
+		labels_right.emplace_back("channel", "right");
+
+		global_metrics.add("bus_current_level_dbfs", labels_left, &metrics.current_level_dbfs[0], Metrics::TYPE_GAUGE);
+		global_metrics.add("bus_current_level_dbfs", labels_right, &metrics.current_level_dbfs[1], Metrics::TYPE_GAUGE);
+		global_metrics.add("bus_peak_level_dbfs", labels_left, &metrics.peak_level_dbfs[0], Metrics::TYPE_GAUGE);
+		global_metrics.add("bus_peak_level_dbfs", labels_right, &metrics.peak_level_dbfs[1], Metrics::TYPE_GAUGE);
+		global_metrics.add("bus_historic_peak_dbfs", metrics.labels, &metrics.historic_peak_dbfs, Metrics::TYPE_GAUGE);
+		global_metrics.add("bus_gain_staging_db", metrics.labels, &metrics.gain_staging_db, Metrics::TYPE_GAUGE);
+		global_metrics.add("bus_compressor_attenuation_db", metrics.labels, &metrics.compressor_attenuation_db, Metrics::TYPE_GAUGE);
+	}
+
 	// Reset resamplers for all cards that don't have the exact same state as before.
 	for (unsigned card_index = 0; card_index < MAX_VIDEO_CARDS; ++card_index) {
 		const DeviceSpec device_spec{InputSourceType::CAPTURE_CARD, card_index};
