@@ -54,8 +54,10 @@ struct Flags {
 	double output_buffer_frames = 6.0;
 	double output_slop_frames = 0.5;
 	int max_input_queue_frames = 6;
+	int http_port = DEFAULT_HTTPD_PORT;
 	bool display_timecode_in_stream = false;
 	bool display_timecode_on_stdout = false;
+	bool enable_quick_cut_keys = false;
 	bool ten_bit_input = false;
 	bool ten_bit_output = false;  // Implies x264_video_to_disk == true and x264_bit_depth == 10.
 	YCbCrInterpretation ycbcr_interpretation[MAX_VIDEO_CARDS];
