@@ -13,6 +13,7 @@ extern "C" {
 #include <QSurfaceFormat>
 #include <string>
 
+#include "basic_stats.h"
 #include "context.h"
 #include "flags.h"
 #include "image_input.h"
@@ -21,7 +22,7 @@ extern "C" {
 
 int main(int argc, char *argv[])
 {
-	parse_flags(argc, argv);
+	parse_flags(PROGRAM_NAGERU, argc, argv);
 
 	if (global_flags.va_display.empty() ||
 	    global_flags.va_display[0] != '/') {
@@ -52,6 +53,10 @@ int main(int argc, char *argv[])
 	QGLFormat::setDefaultFormat(QGLFormat::fromSurfaceFormat(fmt));
 
 	global_share_widget = new QGLWidget();
+	if (!global_share_widget->isValid()) {
+		fprintf(stderr, "Failed to initialize OpenGL. Nageru needs at least OpenGL 3.1 to function properly.\n");
+		exit(1);
+	}
 
 	MainWindow mainWindow;
 	mainWindow.resize(QSize(1500, 850));
