@@ -8,6 +8,8 @@
 #include <mutex>
 #include <queue>
 
+#include <movit/ycbcr.h>
+
 #include "bmusb/bmusb.h"
 
 // An allocator that allocates straight into OpenGL pinned memory.
@@ -17,9 +19,10 @@ class PBOFrameAllocator : public bmusb::FrameAllocator {
 public:
 	// Note: You need to have an OpenGL context when calling
 	// the constructor.
-	PBOFrameAllocator(size_t frame_size,
+	PBOFrameAllocator(bmusb::PixelFormat pixel_format,
+	                  size_t frame_size,
 	                  GLuint width, GLuint height,
-	                  size_t num_queued_frames = 16,  // FIXME: should be 6
+	                  size_t num_queued_frames = 16,
 	                  GLenum buffer = GL_PIXEL_UNPACK_BUFFER_ARB,
 	                  GLenum permissions = GL_MAP_WRITE_BIT,
 	                  GLenum map_bits = GL_MAP_FLUSH_EXPLICIT_BIT);
@@ -30,14 +33,29 @@ public:
 	struct Userdata {
 		GLuint pbo;
 
+		// NOTE: These frames typically go into LiveInputWrapper, which is
+		// configured to accept one type of frame only. In other words,
+		// the existence of a format field doesn't mean you can set it
+		// freely at runtime.
+		bmusb::PixelFormat pixel_format;
+
+		// Used only for PixelFormat_8BitYCbCrPlanar.
+		movit::YCbCrFormat ycbcr_format;
+
 		// The second set is only used for the second field of interlaced inputs.
-		GLuint tex_y[2], tex_cbcr[2];
+		GLuint tex_y[2], tex_cbcr[2];  // For PixelFormat_8BitYCbCr.
+		GLuint tex_cb[2], tex_cr[2];  // For PixelFormat_8BitYCbCrPlanar (which also uses tex_y).
+		GLuint tex_v210[2], tex_444[2];  // For PixelFormat_10BitYCbCr.
+		GLuint tex_rgba[2];  // For PixelFormat_8BitBGRA.
 		GLuint last_width[2], last_height[2];
+		GLuint last_cbcr_width[2], last_cbcr_height[2];
+		GLuint last_v210_width[2];  // PixelFormat_10BitYCbCr.
 		bool last_interlaced, last_has_signal, last_is_connected;
 		unsigned last_frame_rate_nom, last_frame_rate_den;
 	};
 
 private:
+	bmusb::PixelFormat pixel_format;
 	std::mutex freelist_mutex;
 	std::queue<Frame> freelist;
 	GLenum buffer;
