@@ -336,7 +336,7 @@ void QuickSyncEncoderImpl::sps_rbsp(YCbCrLumaCoefficients ycbcr_coefficients, bi
             bitstream_put_ui(bs, 1, 1);  /* colour_description_present_flag */
             {
                 bitstream_put_ui(bs, 1, 8);  /* colour_primaries (1 = BT.709) */
-                bitstream_put_ui(bs, 2, 8);  /* transfer_characteristics (2 = unspecified, since we use sRGB) */
+                bitstream_put_ui(bs, 13, 8);  /* transfer_characteristics (13 = sRGB) */
                 if (ycbcr_coefficients == YCBCR_REC_709) {
                     bitstream_put_ui(bs, 1, 8);  /* matrix_coefficients (1 = BT.709) */
                 } else {
@@ -1656,8 +1656,8 @@ bool QuickSyncEncoderImpl::begin_frame(int64_t pts, int64_t duration, YCbCrLumaC
 			// Create CbCr image.
 			surf->cbcr_egl_image = EGL_NO_IMAGE_KHR;
 			EGLint cbcr_attribs[] = {
-				EGL_WIDTH, frame_width,
-				EGL_HEIGHT, frame_height,
+				EGL_WIDTH, frame_width / 2,
+				EGL_HEIGHT, frame_height / 2,
 				EGL_LINUX_DRM_FOURCC_EXT, fourcc_code('G', 'R', '8', '8'),
 				EGL_DMA_BUF_PLANE0_FD_EXT, EGLint(buf_info.handle),
 				EGL_DMA_BUF_PLANE0_OFFSET_EXT, EGLint(surf->surface_image.offsets[1]),
